package org.dromara.ems.info.service;

import org.dromara.ems.info.domain.SparePartsUsageRecord;

import java.util.List;

/**
 * 动力能源部行输科备件领用更换记录Service接口
 * 
 * @author Yinq
 * @date 2025-06-05
 */
public interface ISparePartsUsageRecordService 
{
    /**
     * 查询动力能源部行输科备件领用更换记录
     * 
     * @param id 动力能源部行输科备件领用更换记录主键
     * @return 动力能源部行输科备件领用更换记录
     */
    public SparePartsUsageRecord selectSparePartsUsageRecordById(Long id);

    /**
     * 查询动力能源部行输科备件领用更换记录列表
     * 
     * @param sparePartsUsageRecord 动力能源部行输科备件领用更换记录
     * @return 动力能源部行输科备件领用更换记录集合
     */
    public List<SparePartsUsageRecord> selectSparePartsUsageRecordList(SparePartsUsageRecord sparePartsUsageRecord);

    /**
     * 新增动力能源部行输科备件领用更换记录
     * 
     * @param sparePartsUsageRecord 动力能源部行输科备件领用更换记录
     * @return 结果
     */
    public int insertSparePartsUsageRecord(SparePartsUsageRecord sparePartsUsageRecord);

    /**
     * 修改动力能源部行输科备件领用更换记录
     * 
     * @param sparePartsUsageRecord 动力能源部行输科备件领用更换记录
     * @return 结果
     */
    public int updateSparePartsUsageRecord(SparePartsUsageRecord sparePartsUsageRecord);

    /**
     * 批量删除动力能源部行输科备件领用更换记录
     * 
     * @param ids 需要删除的动力能源部行输科备件领用更换记录主键集合
     * @return 结果
     */
    public int deleteSparePartsUsageRecordByIds(Long[] ids);

    /**
     * 删除动力能源部行输科备件领用更换记录信息
     * 
     * @param id 动力能源部行输科备件领用更换记录主键
     * @return 结果
     */
    public int deleteSparePartsUsageRecordById(Long id);

    /**
     * 导入动力能源部行输科备件领用更换记录数据
     *
     * @param recordList 记录数据列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    public String importSparePartsUsageRecord(List<SparePartsUsageRecord> recordList, Boolean isUpdateSupport, String operName);
}
